@@ -24,6 +24,7 @@
 #include "keyboard.h"
 #include "tutor.h"
 #include "translation.h"
+#include "accuracy.h"
 #include "adaptability.h"
 
 /**********************************************************************
@@ -38,17 +39,32 @@ adapt_draw_random_pattern ()
 	gchar *utf8_text;
 	gunichar text[WORDS * (MAX_WORD_LEN + 1) + 3];
 	gunichar word[MAX_WORD_LEN + 1];
+	gboolean special;
+	gboolean word_ok;
 
 	hlp = main_preferences_get_string ("interface", "language");
+
+	special = (accur_error_total () > ERROR_LIMIT);
+	if (special)
+		gtk_widget_show (get_wg ("kadro_tro_eraroj"));
+	else
+		gtk_widget_hide (get_wg ("kadro_tro_eraroj"));
+
 	for (i = 0; i < LINES; i++)
 	{			/* paragraphs per exercise */
 		tidx = 0;
 		for (j = 0; j < WORDS; j++)
 		{		/* words per paragraph */
-			if (rand () % 15)
-				adapt_create_word (word);
-			else
-				adapt_create_number (word);
+			if (special)
+				word_ok = accur_create_word (word);
+
+			if (!special || !word_ok)
+			{
+				if (rand () % 15)
+					adapt_create_word (word);
+				else
+					adapt_create_number (word);
+			}
 
 			if (j == 0)
 				word[0] = keyb_unichar_toupper (word[0]);
@@ -68,6 +84,7 @@ adapt_draw_random_pattern ()
 		tutor_draw_paragraph (utf8_text);
 		g_free (utf8_text);
 	}
+
 	g_free (hlp);
 }
 
@@ -183,12 +200,15 @@ adapt_comment (gdouble accuracy)
 	 * Comments
 	 */
 	if (accuracy < 50)
-		tmp_str =
-			g_strdup (_
+	{
+		/*
+		tmp_str = g_strdup (_
 				  (" Your error rate is too high.\n"
 				   " Maybe you are not ready to practice this exercise.\n"
 				   " Did you accomplish most of the basic course lessons?\n"));
-
+		*/
+		tmp_str = g_strdup (":-(\n");
+	}
 	else if (accuracy < 90)
 		tmp_str = g_strdup (_(" Your accuracy rate is below 90%...\n"
 				      " Could you please try again to improve it?\n"));
@@ -204,12 +224,17 @@ adapt_comment (gdouble accuracy)
 				" or maybe you're getting upset, so go to other kind of exercise.\n"),
 			       	tutor_goal_accuracy ());
 	else
+	{
 		tmp_str = g_strdup_printf (_(" Very good!\n"
 				      " You succeeded with an accuracy rate above %.0f%%.\n"
 				      " Now it is time to increase your velocity.\n"
 				      " Go to the 3rd exercise at the main menu.\n"),
 			       	tutor_goal_accuracy ());
 
+		accur_reset ();
+		gtk_widget_hide (get_wg ("kadro_tro_eraroj"));
+	}
+
 	wg = get_wg ("text_tutor");
 	buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (wg));
 	gtk_text_buffer_insert_at_cursor (buf, tmp_str, strlen (tmp_str));
