@@ -108,7 +108,7 @@ basic_init_char_set ()
 	if (basic.lesson > 43 && basic.lesson <= 50)
 	{
 		lesson_file = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "basic_lesson_%i.txt",
-			       	main_get_user_dir (), basic.lesson);
+			       	main_path_user (), basic.lesson);
 		if (g_file_get_contents (lesson_file, &lesson_str, NULL, NULL))
 		{
 			tmpuc = g_utf8_to_ucs4_fast (lesson_str, -1, &basic.char_set_size);
@@ -139,7 +139,7 @@ basic_init_char_set ()
 	/*
 	 * Open the lesson file
 	 */
-	lesson_file = g_build_filename (main_get_data_path (), "basic_lessons.txt", NULL);
+	lesson_file = g_build_filename (main_path_data (), "basic_lessons.txt", NULL);
 	fh = (FILE *) g_fopen (lesson_file, "r");
 	g_free (lesson_file);
 	if (!fh)
@@ -227,7 +227,7 @@ basic_save_lesson (gchar * charset)
 	gchar *lesson_file;
 	FILE *fh;
 
-	lesson_file = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "basic_lesson_%i.txt", main_get_user_dir (), basic.lesson);
+	lesson_file = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "basic_lesson_%i.txt", main_path_user (), basic.lesson);
 	fh = (FILE *) g_fopen (lesson_file, "w");
 	if (fh == NULL)
 		g_warning ("couldn't save the file:\n %s", lesson_file);
@@ -320,9 +320,12 @@ basic_comment (gdouble accuracy)
 	 * Comments
 	 */
 	if (accuracy < tutor_goal_accuracy ())
+		/*
 		tmp_str = g_strdup_printf (_(" You did not succeed.\n"
 					     " The accuracy must be above %.0f%%.\n"
 					     " Try again!\n"), tutor_goal_accuracy ());
+	        */
+		tmp_str = g_strdup (":-(\n");
 	else
 	{
 		basic_set_lesson (basic.lesson + 1);
