@@ -30,12 +30,16 @@
 #include "basic.h"
 #include "velocity.h"
 #include "fluidness.h"
+#include "accuracy.h"
 #include "top10.h"
 #include "callbacks.h"
 
 /*
  * Variables
  */
+GtkClipboard *clipboard = NULL;
+GtkClipboard *clipboard_2 = NULL;
+
 extern gchar *KEYB_CUSTOM;
 extern gchar *KEYB_EDIT;
 extern gchar *OTHER_DEFAULT;
@@ -44,9 +48,6 @@ static gboolean callbacks_shield = FALSE;
 static gboolean mesg_drag_drop = FALSE;
 static gchar *other_renaming_undo = NULL;
 
-GtkClipboard *clipboard = NULL;
-GtkClipboard *clipboard_2 = NULL;
-
 void
 callbacks_shield_set (gboolean state)
 {
@@ -159,8 +160,6 @@ on_combobox_kbd_variant_changed (GtkComboBox *cmb, gpointer user_data)
 G_MODULE_EXPORT void
 on_window_main_destroy (GtkObject *obj, gpointer data)
 {
-	gint x, y;
-
 	if (callbacks_shield)
 		return;
 
@@ -187,6 +186,8 @@ on_text_tutor_realize (GtkWidget * widget, gpointer user_data)
 {
 	gboolean beep;
 	gchar *tmp_font;
+	gchar *color_cursor_blink_fg;
+	gchar *color_cursor_blink_bg;
 	GtkWidget *wg;
 	GtkTextBuffer *buf;
 	PangoFontDescription *font_desc;
@@ -197,24 +198,51 @@ on_text_tutor_realize (GtkWidget * widget, gpointer user_data)
 	 */
 	buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
 
-	gtk_text_buffer_create_tag (buf, "char_untouched", "background", TUTOR_CREAM, "foreground",
-		      	 	    TUTOR_BLACK, "underline", PANGO_UNDERLINE_NONE, NULL);
+	gtk_text_buffer_create_tag (buf, "char_untouched",
+		       	"background", TUTOR_CREAM,
+		       	"foreground", TUTOR_BLACK,
+		       	"underline", PANGO_UNDERLINE_NONE, NULL);
 
-	gtk_text_buffer_create_tag (buf, "char_wrong", "background", TUTOR_RED_LITE, "foreground",
-				    TUTOR_RED, "underline", PANGO_UNDERLINE_NONE, NULL);
+	gtk_text_buffer_create_tag (buf, "char_wrong",
+		       	"background", TUTOR_RED_LITE,
+		       	"foreground", TUTOR_RED,
+		       	"underline", PANGO_UNDERLINE_NONE, NULL);
 
-	gtk_text_buffer_create_tag (buf, "char_correct", "background", TUTOR_CREAM, "foreground",
-				    TUTOR_GREEN, "underline", PANGO_UNDERLINE_NONE, NULL);
+	gtk_text_buffer_create_tag (buf, "char_correct",
+		       	"background", TUTOR_CREAM,
+		       	"foreground", TUTOR_GREEN,
+		       	"underline", PANGO_UNDERLINE_NONE, NULL);
 
 	gtk_text_buffer_create_tag (buf, "char_retouched",
-				    "background", TUTOR_GRAY, "foreground", TUTOR_BROWN,
-				    "underline", PANGO_UNDERLINE_NONE, NULL);
+			    "background", TUTOR_GRAY,
+			    "foreground", TUTOR_BROWN,
+			    "underline", PANGO_UNDERLINE_NONE, NULL);
 
-	gtk_text_buffer_create_tag (buf, "cursor_blink", "background", TUTOR_YELLOW, "foreground",
-				    TUTOR_BLACK, "underline", PANGO_UNDERLINE_NONE, NULL);
+	color_cursor_blink_bg = main_preferences_get_string ("colors", "cursor_blink_bg");
+	color_cursor_blink_fg = main_preferences_get_string ("colors", "cursor_blink_fg");
+	if (color_cursor_blink_fg && color_cursor_blink_bg)
+	{
+		gtk_text_buffer_create_tag (buf, "cursor_blink",
+			       	"background", color_cursor_blink_bg,
+			       	"foreground", color_cursor_blink_fg,
+			       	"underline", PANGO_UNDERLINE_NONE, NULL);
+	}
+	else
+	{
+		gtk_text_buffer_create_tag (buf, "cursor_blink",
+			       	"background", TUTOR_YELLOW,
+			       	"foreground", TUTOR_BLACK,
+			       	"underline", PANGO_UNDERLINE_NONE, NULL);
+	}
+	if (color_cursor_blink_fg)
+		g_free (color_cursor_blink_fg);
+	if (color_cursor_blink_bg)
+		g_free (color_cursor_blink_bg);
 
-	gtk_text_buffer_create_tag (buf, "text_intro", "background", TUTOR_WHITE, "foreground",
-				    TUTOR_BLACK, "underline", PANGO_UNDERLINE_NONE, NULL);
+	gtk_text_buffer_create_tag (buf, "text_intro",
+		       	"background", TUTOR_WHITE,
+		       	"foreground", TUTOR_BLACK,
+		       	"underline", PANGO_UNDERLINE_NONE, NULL);
 
 	tmp_font = main_preferences_get_string ("tutor", "lesson_font");
 	if (tmp_font == NULL)
@@ -236,7 +264,6 @@ on_text_tutor_realize (GtkWidget * widget, gpointer user_data)
 
 	/* Change default background color throughout the widget */
 	gdk_color_parse (TUTOR_CREAM, &color);
-	//gdk_color_parse ("#FFFFFF", &color);
 	gtk_widget_modify_base (widget, GTK_STATE_INSENSITIVE, &color);
 
 	/*
@@ -352,8 +379,7 @@ on_togglebutton_edit_basic_lesson_toggled (GtkToggleButton * togglebutton, gpoin
 		g_free (tmp_name);
 
 		callbacks_shield_set (FALSE);
-		//gtk_widget_grab_focus (get_wg ("entry_mesg"));
-		gtk_widget_grab_focus (tutor_entry_mesg ()); // Sexy...
+		gtk_widget_grab_focus (get_wg ("entry_mesg"));
 	}
 }
 
@@ -501,29 +527,35 @@ on_window_tutor_destroy (GtkObject * object, gpointer user_data)
 G_MODULE_EXPORT void
 on_button_tutor_close_clicked (GtkButton *button, gpointer user_data)
 {
-	gint x, y;
-
 	on_window_tutor_destroy (NULL, NULL);
 }
 
+static void
+cb_quick_restart ()
+{
+	if (tutor_get_query () == QUERY_END)
+		return;
+
+	tutor_set_query (QUERY_INTRO);
+	tutor_process_touch (L'\0');
+}
+
 G_MODULE_EXPORT void
 on_button_tutor_restart_clicked (GtkButton * button, gpointer user_data)
 {
-	if (tutor_get_query () == QUERY_END)
-		return;
-
-	tutor_set_query (QUERY_INTRO);
-	tutor_process_touch (L'\0');
+	cb_quick_restart ();
 }
 
 G_MODULE_EXPORT void
 on_eventbox_tutor_restart_grab_focus (GtkWidget * widget, gpointer user_data)
 {
-	if (tutor_get_query () == QUERY_END)
-		return;
+	cb_quick_restart ();
+}
 
-	tutor_set_query (QUERY_INTRO);
-	tutor_process_touch (L'\0');
+G_MODULE_EXPORT void
+on_entry_mesg_icon_release (GtkEntry *entry, GtkEntryIconPosition pos, GdkEvent *event, gpointer user_data)
+{
+	cb_quick_restart ();
 }
 
 /* Managing the keyboard/messages entry of the tutor window
@@ -685,29 +717,29 @@ on_button_top10_go_www_clicked         (GtkButton       *button,
                                         gpointer         user_data)
 {
 	gchar *url;
-	gchar *kmd;
+	gchar *cmd;
 	
 	url = gtk_widget_get_tooltip_text (get_wg ("button_top10_go_www"));
 	if (g_file_test ("/usr/bin/x-www-browser", G_FILE_TEST_IS_EXECUTABLE))
-		kmd = g_strdup_printf ("x-www-browser '%s' &", url);
+		cmd = g_strdup_printf ("x-www-browser '%s' &", url);
 	else if (g_file_test ("/usr/bin/gnome-www-browser", G_FILE_TEST_IS_EXECUTABLE))
-		kmd = g_strdup_printf ("gnome-www-browser '%s' &", url);
+		cmd = g_strdup_printf ("gnome-www-browser '%s' &", url);
 	else if (g_file_test ("/usr/bin/konqueror", G_FILE_TEST_IS_EXECUTABLE))
-		kmd = g_strdup_printf ("konqueror '%s' &", url);
+		cmd = g_strdup_printf ("konqueror '%s' &", url);
 	else if (g_file_test ("/usr/bin/firefox", G_FILE_TEST_IS_EXECUTABLE))
-		kmd = g_strdup_printf ("firefox '%s' &", url);
+		cmd = g_strdup_printf ("firefox '%s' &", url);
 	else if (g_file_test ("/usr/bin/epiphany", G_FILE_TEST_IS_EXECUTABLE))
-		kmd = g_strdup_printf ("epiphany '%s' &", url);
+		cmd = g_strdup_printf ("epiphany '%s' &", url);
 	else if (g_file_test ("/usr/bin/galeon", G_FILE_TEST_IS_EXECUTABLE))
-		kmd = g_strdup_printf ("galeon '%s' &", url);
+		cmd = g_strdup_printf ("galeon '%s' &", url);
 	else
-		kmd = g_strdup_printf ("sensible-browser '%s' &", url);
+		cmd = g_strdup_printf ("sensible-browser '%s' &", url);
 
-	top10_message (kmd);
-	g_printf ("Performing:\n %s\n", kmd);
-	system (kmd);
+	top10_message (cmd);
+	g_printf ("Performing:\n %s\n", cmd);
+	system (cmd);
 	g_free (url);
-	g_free (kmd);
+	g_free (cmd);
 }
 
 G_MODULE_EXPORT void
@@ -723,9 +755,7 @@ on_button_top10_publish_clicked (GtkButton * button, gpointer user_data)
 
 	top10_message (_("Connecting..."));
 
-#ifdef G_OS_UNIX
 	g_idle_add ((GSourceFunc) top10_global_publish, NULL);
-#endif
 }
 
 G_MODULE_EXPORT void
@@ -741,9 +771,7 @@ on_button_top10_update_clicked (GtkButton * button, gpointer user_data)
 
 	top10_message (_("Connecting..."));
 
-#ifdef G_OS_UNIX
 	g_idle_add ((GSourceFunc) top10_global_update, NULL);
-#endif
 }
 
 G_MODULE_EXPORT void
@@ -820,10 +848,8 @@ G_MODULE_EXPORT void
 on_button_kb_remove_clicked (GtkButton * button, gpointer user_data)
 {
 	gchar *tmp_path = NULL;
-	GtkWidget *dialog_confirm;
-	GtkWidget *wg;
 
-	tmp_path = g_strconcat (main_get_user_dir (), G_DIR_SEPARATOR_S, keyb_get_name (), ".kbd", NULL);
+	tmp_path = g_strconcat (main_path_user (), G_DIR_SEPARATOR_S, keyb_get_name (), ".kbd", NULL);
 	if (! g_file_test (tmp_path, G_FILE_TEST_IS_REGULAR))
 	{
 		gdk_beep ();
@@ -849,7 +875,7 @@ on_button_kb_save_clicked (GtkButton * button, gpointer user_data)
 		g_free (tmp);
 		tmp = g_strdup (KEYB_AUTO_SAVE);
 	}
-	tmp_path = g_strconcat (main_get_user_dir (), G_DIR_SEPARATOR_S, tmp, ".kbd", NULL);
+	tmp_path = g_strconcat (main_path_user (), G_DIR_SEPARATOR_S, tmp, ".kbd", NULL);
 	keyb_set_name (tmp);
 	g_free (tmp);
 
@@ -876,8 +902,6 @@ on_button_keyboard_next_clicked (GtkButton *but, gpointer user_data)
 G_MODULE_EXPORT void
 on_button_keyboard_close_clicked (GtkButton *but, gpointer user_data)
 {
-	GtkWidget *wg;
-
 	hints_demo_fingers (0);
 	gtk_widget_hide (get_wg ("window_keyboard"));
 }
@@ -885,8 +909,6 @@ on_button_keyboard_close_clicked (GtkButton *but, gpointer user_data)
 G_MODULE_EXPORT void
 on_button_keyboard_hands_clicked (GtkButton *but, gpointer user_data)
 {
-	GtkWidget *wg;
-
 	if (GTK_WIDGET_VISIBLE (get_wg ("window_tutor")))
 		if (GTK_WIDGET_VISIBLE (get_wg ("hbox_keyboard_hints")))
 		{
@@ -963,7 +985,7 @@ on_toggle_shift2_grab_focus (GtkToggleButton *tg, gpointer user_data)
 
 /* All the other keys
  */
-void
+G_MODULE_EXPORT void
 on_virtual_key_grab_focus (GtkWidget *wg, gpointer user_data)
 {
 	if (callbacks_shield)
@@ -975,7 +997,7 @@ on_virtual_key_grab_focus (GtkWidget *wg, gpointer user_data)
 		keyb_edit_button (GTK_BUTTON (wg));
 }
 
-void
+G_MODULE_EXPORT void
 on_virtual_key_clicked (GtkButton * button, gpointer user_data)
 {
 	if (callbacks_shield)
@@ -987,7 +1009,7 @@ on_virtual_key_clicked (GtkButton * button, gpointer user_data)
 		keyb_edit_button (button);
 }
 
-void
+G_MODULE_EXPORT void
 on_virtual_key_changed (GtkEditable *edit, gpointer user_data)
 {
 	gunichar ch;
@@ -1080,21 +1102,22 @@ on_button_confirm_yes_clicked (GtkButton * button, gpointer user_data)
 
 	else if (g_str_equal (action, "RESET"))
 	{
-		file = g_build_filename (main_get_user_dir (), "stat_basic.txt", NULL);
+		file = g_build_filename (main_path_stats (), "stat_basic.txt", NULL);
 		g_unlink (file);
 		g_free (file);
-		file = g_build_filename (main_get_user_dir (), "stat_adapt.txt", NULL);
+		file = g_build_filename (main_path_stats (), "stat_adapt.txt", NULL);
 		g_unlink (file);
 		g_free (file);
-		file = g_build_filename (main_get_user_dir (), "stat_velo.txt", NULL);
+		file = g_build_filename (main_path_stats (), "stat_velo.txt", NULL);
 		g_unlink (file);
 		g_free (file);
-		file = g_build_filename (main_get_user_dir (), "stat_fluid.txt", NULL);
+		file = g_build_filename (main_path_stats (), "stat_fluid.txt", NULL);
 		g_unlink (file);
 		g_free (file);
-		file = g_build_filename (main_get_user_dir (), "scores_fluid.txt", NULL);
+		file = g_build_filename (main_path_stats (), "scores_fluid.txt", NULL);
 		g_unlink (file);
 		g_free (file);
+		accur_reset ();
 
 		basic_set_lesson (1);
 
@@ -1134,8 +1157,6 @@ on_window_hints_check_resize (GtkContainer *cont, gpointer user_data)
 	static int i;
 	static GTimer *wait = NULL;
 	gint dx, dy;
-	GdkPixbuf *pbuf;
-	GdkPixbuf *pbuf2;
 
 	//if (callbacks_shield)
 		return;
@@ -1192,14 +1213,23 @@ on_combobox_stat_module_changed (GtkComboBox *cmb, gpointer user_data)
 	tmp = g_strdup_printf ("%s %s", _("Speed"), _("(WPM)"));
 	gtk_combo_box_insert_text (GTK_COMBO_BOX (get_wg ("combobox_stat_type")), 1, tmp);
 	g_free (tmp);
-	if (gtk_combo_box_get_active (cmb) == 3)
+	switch (gtk_combo_box_get_active (cmb))
 	{
+		/* Uncomment this in order to enable the error plottings
+		*/
+	case 1:
+		tmp = g_strdup_printf ("%s", _("Errors"));
+		gtk_combo_box_insert_text (GTK_COMBO_BOX (get_wg ("combobox_stat_type")), 2, tmp);
+		g_free (tmp);
+		break;
+	case 3:
 		tmp = g_strdup_printf ("%s (%%)", _("Fluidity"));
 		gtk_combo_box_insert_text (GTK_COMBO_BOX (get_wg ("combobox_stat_type")), 2, tmp);
 		g_free (tmp);
 		tmp = g_strdup_printf ("%s (0-10)", _("Score"));
 		gtk_combo_box_insert_text (GTK_COMBO_BOX (get_wg ("combobox_stat_type")), 3, tmp);
 		g_free (tmp);
+		break;
 	}
 	gtk_combo_box_set_active (GTK_COMBO_BOX (get_wg ("combobox_stat_type")), 0);
 	callbacks_shield_set (FALSE);
@@ -1225,7 +1255,12 @@ on_combobox_stat_type_changed (GtkComboBox *cmb, gpointer user_data)
 	active = gtk_combo_box_get_active ( GTK_COMBO_BOX (get_wg ("combobox_stat_type")) );
 	if (active < 0)
 		return;
-	plot_draw_chart (active + 1);
+
+	if (gtk_combo_box_get_active (GTK_COMBO_BOX (get_wg ("combobox_stat_module"))) == 1 &&
+			active == 2)
+		plot_draw_chart (6);
+	else
+		plot_draw_chart (active + 1);
 }
 
 G_MODULE_EXPORT void
@@ -1257,7 +1292,7 @@ on_button_stat_close_clicked (GtkButton * button, gpointer user_data)
 G_MODULE_EXPORT void
 on_databox_hovered (GtkDatabox *dbox, GdkEventMotion *event, gpointer user_data)
 {
-	plot_pointer_update (event->x, event->y);
+	plot_pointer_update (event->x);
 }
 
 /**********************************************************************
@@ -1392,7 +1427,7 @@ on_button_other_remove_clicked (GtkButton * button, gpointer user_data)
 		return;
 	}
 
-	tmp_name = g_build_filename (main_get_user_dir (), tmp_str, NULL);
+	tmp_name = g_build_filename (main_path_user (), tmp_str, NULL);
 	g_free (tmp_str);
 
 	if (tutor_get_type () == TT_VELO)
