@@ -17,7 +17,6 @@
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <sys/stat.h>
 #include <glib.h>
 #include <glib/gstdio.h>
 #include <pango/pango-attributes.h>
@@ -29,10 +28,7 @@
 #include "translation.h"
 #include "keyboard.h"
 #include "tutor.h"
-#include "basic.h"
-#include "adaptability.h"
-#include "velocity.h"
-#include "fluidness.h"
+#include "accuracy.h"
 #include "top10.h"
 #include "main.h"
 
@@ -41,62 +37,51 @@
  */
 GtkBuilder *gui;
 
-static GKeyFile *preferences = NULL;
-
-static struct
-{
-	struct
-	{
-		gchar *user;
-		gchar *data;
-		gchar *score;
-	} path;	
-	gboolean curl_ok;
-} general;
-
 gchar *KEYB_CUSTOM;
 gchar *KEYB_EDIT;
 gchar *OTHER_DEFAULT;
 
-/*******************************************************************************
- * Internal functions
- */
-void main_initialize_global_variables (void);
-
-void main_window_init (void);
+static GKeyFile *preferences = NULL;
+static gboolean curl_ok;
+static struct
+{
+	gchar *user;
+	gchar *stats;
+	gchar *data;
+	gchar *score;
+} path;
 
 /*******************************************************************************
  * Interface functions
  */
 gchar *
-main_get_data_path ()
+main_path_user ()
 {
-	return (general.path.data);
-}
-
-void
-main_set_data_path (gchar *path)
-{
-	g_free (general.path.data);
-	general.path.data = g_strdup (path);
+	return (path.user);
 }
 
 gchar *
-main_get_user_dir ()
+main_path_stats ()
 {
-	return (general.path.user);
+	return (path.stats);
 }
 
 gchar *
-main_get_score_path ()
+main_path_data ()
 {
-	return (general.path.score);
+	return (path.data);
+}
+
+gchar *
+main_path_score ()
+{
+	return (path.score);
 }
 
 gboolean
-main_get_curl_ok ()
+main_curl_ok ()
 {
-	return (general.curl_ok);
+	return (curl_ok);
 }
 
 gboolean
@@ -112,13 +97,13 @@ main_preferences_remove (gchar * group, gchar * key)
 }
 
 gchar *
-main_preferences_get_string (gchar *group, gchar *key)
+main_preferences_get_string (gchar * group, gchar * key)
 {
 	return (g_key_file_get_string (preferences, group, key, NULL));
 }
 
 void
-main_preferences_set_string (gchar *group, gchar *key, gchar *value)
+main_preferences_set_string (gchar * group, gchar * key, gchar * value)
 {
 	g_key_file_set_string (preferences, group, key, value);
 }
@@ -157,7 +142,7 @@ main_preferences_save ()
 	 * Save preferences
 	 */
 	assert_user_dir ();
-	tmp_name = g_build_filename (general.path.user, "preferences.ini", NULL);
+	tmp_name = g_build_filename (main_path_user (), "preferences.ini", NULL);
 	fh = (FILE *) g_fopen (tmp_name, "w");
 	if (fh == NULL)
 		g_warning ("couldn't save your preferences at the user folder:\n %s", tmp_name);
@@ -175,116 +160,91 @@ main_preferences_save ()
 	g_free (tmp_name);
 }
 
-/*******************************************************************************
- * Main program
+/*
+ * End of interface, start of private functions
  */
-int
-main (int argc, char *argv[])
+static void
+main_stats_relocate (gchar * fname)
 {
-	gchar *tmp;
-	gboolean success = FALSE;
+	gchar *old;
+	gchar *new;
 
-	/* Localization
-	 */
-#ifdef ENABLE_NLS
-	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-	textdomain (GETTEXT_PACKAGE);
-#endif
-
-	/* Command-line arguments
-	 */
-	if (argc == 2)
+	g_assert (fname);
+	old = g_build_filename (main_path_user (), fname, NULL);
+	if (!g_file_test (old, G_FILE_TEST_IS_REGULAR))
 	{
-		if (g_str_equal (argv[1], "--versio") || g_str_equal (argv[1], "--version"))
-		{
-			g_print (PACKAGE " - " VERSION "\n");
-			return 0;
-		}
-#ifdef G_OS_UNIX
-		if (g_str_equal (argv[1], "-a"))
-		{
-			main_initialize_global_variables ();
-			general.curl_ok = curl_global_init (CURL_GLOBAL_WIN32) == CURLE_OK ? TRUE : FALSE;
-			top10_global_rank ();
-			if (general.curl_ok) curl_global_cleanup ();
-			return 0;
-		}
-#endif
+		g_free (old);
+		return;
 	}
-
-#ifdef G_OS_UNIX
-	general.curl_ok = curl_global_init (CURL_GLOBAL_WIN32) == CURLE_OK ? TRUE : FALSE;
-#else
-	general.curl_ok = 0;
-#endif
-
-	gtk_init (&argc, &argv);
-
-	main_initialize_global_variables ();	/* Here the locale is got. */
-
-	/* Create all the interface stuff
-	 */
-	gui = gtk_builder_new ();
-	tmp = g_build_filename (main_get_data_path (), "klavaro.ui", NULL);
-	if (g_file_test (tmp, G_FILE_TEST_IS_REGULAR))
-		success = gtk_builder_add_from_file (gui, tmp, NULL);
+	new = g_build_filename (main_path_stats (), fname, NULL);
+	if (g_rename (old, new) != 0)
+		g_print ("Failed to relocate stats file.\n\tCheck your old file: %s\n\tNew location to be used:%s\n",
+			 old, new);
 	else
-		g_error ("GUI file not found. Aborting.\n %s", tmp);
-	if (!success)
-		g_error ("GUI file found but couldn't create the GUI. Aborting.");
-	if (!g_module_supported ())
-		g_error ("GUI created but can't connect signals.");
-	g_free (tmp);
-	gtk_builder_connect_signals (gui, NULL);
-
-	main_window_init ();	/* and initialize its parameters */
-
-	gtk_main ();
-
-	return 0;
+		g_print ("File relocated.\n\tFrom: %s\n\tTo: %s\n", old, new);
+	g_free (old);
+	g_free (new);
 }
 
 /**********************************************************************
  * Initialize the value of the global variables
  */
-void
+static void
 main_initialize_global_variables ()
 {
 	gchar *tmp;
+	gchar *path_score_old;
+	gchar *fname;
+	gint chr;
 	FILE *fh;
+	FILE *fh_from;
+	FILE *fh_to;
+	GDir *kscdir;
 
 	/* Set the home user dir (update to new config dir)
 	 */
 	tmp = g_build_filename (g_get_home_dir (), ".klavaro", NULL);
-	general.path.user = g_build_filename (g_get_user_config_dir (), "klavaro", NULL);
+	path.user = g_build_filename (g_get_user_config_dir (), "klavaro", NULL);
 	if (g_file_test (tmp, G_FILE_TEST_IS_DIR))
 	{
-#	ifdef G_OS_UNIX
-		g_mkdir (g_get_user_config_dir (), S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH);
-#	else
-		g_mkdir (g_get_user_config_dir (), 0xFFFF);
-#	endif
-		if (g_rename (tmp, general.path.user) != 0)
+		g_mkdir (g_get_user_config_dir (), DIR_PERM);
+		if (g_rename (tmp, path.user) != 0)
 		{
-			g_free (general.path.user);
-			general.path.user = g_strdup (tmp);
+			g_free (path.user);
+			path.user = g_strdup (tmp);
 		}
 	}
 	g_free (tmp);
 
+	/* Set the home user stats dir (update to new local/share dir)
+	 */
+	if (UNIX_OK)
+		path.stats = g_build_filename (g_get_user_data_dir (), "klavaro", NULL);
+	else
+		path.stats = g_build_filename (g_get_user_config_dir (), "klavaro", NULL);
+	if (!g_file_test (path.stats, G_FILE_TEST_IS_DIR))
+	{
+		g_mkdir_with_parents (path.stats, DIR_PERM);
+		main_stats_relocate ("stat_basic.txt");
+		main_stats_relocate ("stat_adapt.txt");
+		main_stats_relocate ("stat_velo.txt");
+		main_stats_relocate ("stat_fluid.txt");
+		main_stats_relocate ("scores_fluid.txt");
+		main_stats_relocate ("deviation_fluid.txt");
+	}
+
 	/* Get a valid data path.
 	 * First searches the path at the source directory.
 	 */
-	general.path.data = g_build_filename ("..", "data", NULL);
-	tmp = g_build_filename (general.path.data, "basic_lessons.txt", NULL);
+	path.data = g_build_filename ("..", "data", NULL);
+	tmp = g_build_filename (path.data, "basic_lessons.txt", NULL);
 	fh = (FILE *) g_fopen (tmp, "r");
 	if (fh == NULL)
 	{
-		g_free (general.path.data);
+		g_free (path.data);
 		g_free (tmp);
-		general.path.data = g_build_filename (PACKAGE_DATA_DIR, PACKAGE, NULL);
-		tmp = g_build_filename (general.path.data, "basic_lessons.txt", NULL);
+		path.data = g_build_filename (PACKAGE_DATA_DIR, PACKAGE, NULL);
+		tmp = g_build_filename (path.data, "basic_lessons.txt", NULL);
 		fh = (FILE *) g_fopen (tmp, "r");
 	}
 	if (fh == NULL)
@@ -293,18 +253,56 @@ main_initialize_global_variables ()
 	g_free (tmp);
 
 	/* Get a valid scoring path.
+	 * Updating from /var/games/klavaro to $XDG_USER_DATA_DIR/klavaro/ksc
 	 */
 	if (UNIX_OK)
-		general.path.score = g_strdup ("/var/games/klavaro");
+		path_score_old = g_strdup ("/var/games/klavaro");
 	else
-		general.path.score =
-			g_build_filename ((g_get_system_data_dirs ())[0], PACKAGE, NULL);
+		path_score_old = g_build_filename ((g_get_system_data_dirs ())[0], PACKAGE, NULL);
+	path.score = g_build_filename (path.stats, "ksc", NULL);
+	if (!g_file_test (path.score, G_FILE_TEST_IS_DIR))
+	{
+		g_mkdir_with_parents (path.score, DIR_PERM);
+		kscdir = g_dir_open (path_score_old, 0, NULL);
+		if (kscdir)
+		{
+			while ((fname = (gchar *) g_dir_read_name (kscdir)))
+			{
+				if (!g_str_has_suffix (fname, ".ksc"))
+					continue;
+
+				tmp = g_build_filename (path_score_old, fname, NULL);
+				fh_from = g_fopen (tmp, "rb");
+				g_free (tmp);
+				if (!fh_from)
+					continue;
+
+				tmp = g_build_filename (path.score, fname, NULL);
+				fh_to = g_fopen (tmp, "wb");
+				g_free (tmp);
+				if (!fh_to)
+				{
+					fclose (fh_from);
+					continue;
+				}
+
+				// Copy from to
+				while ((chr = getc (fh_from)) != EOF)
+					putc (chr, fh_to);
+
+				fclose (fh_from);
+				fclose (fh_to);
+			}
+			g_dir_close (kscdir);
+		}
+	}
+	//g_message (path.score);
 
 	/* Retrieve initial or saved preferences
 	 */
 	preferences = g_key_file_new ();
-	tmp = g_build_filename (general.path.user, "preferences.ini", NULL);
-	if (! g_file_test (tmp, G_FILE_TEST_EXISTS))
+	tmp = g_build_filename (main_path_user (), "preferences.ini", NULL);
+	if (!g_file_test (tmp, G_FILE_TEST_EXISTS))
 	{
 		g_free (tmp);
 		tmp = g_strdup ("/etc/klavaro_preferences.ini");
@@ -318,35 +316,20 @@ main_initialize_global_variables ()
 	trans_init_language_env ();
 	srand (time (0));
 	tutor_init_timers ();
+	accur_init ();
 
 	KEYB_CUSTOM = g_strdup (_("(Custom)"));
 	KEYB_EDIT = g_strdup (_("(Edit custom)"));
 	OTHER_DEFAULT = g_strdup (_("(Default)"));
 }
 
-void
-main_set_pixmap (gchar *widget, gchar *image)
-{
-	gchar *tmp;
-	GtkImage *img;
-
-	tmp = g_build_filename (general.path.data, image, NULL);
-	img = GTK_IMAGE (get_wg (widget));
-	gtk_image_set_from_file (img, tmp);
-	g_free (tmp);
-}
-
 /*******************************************************************************
  * Initialize some interface widgets
  */
-void
+static void
 main_window_init ()
 {
-	static GList *iconlist = NULL;
-	static GdkPixbuf *icon[5];
-	gint i;
 	gchar *tmp;
-	GtkWidget *wg;
 	PangoAttrList *palist;
 
 	/* Set the language
@@ -369,12 +352,12 @@ main_window_init ()
 
 	/* Set pixmaps
 	 */
-	main_set_pixmap ("image_fluid", "fluid.png");
-	main_set_pixmap ("image_keyboard", "key.png");
-	main_set_pixmap ("image_beep", "beep.png");
-	main_set_pixmap ("image_progress", "progress.png");
-	main_set_pixmap ("image_other", "other.png");
-	main_set_pixmap ("image_top10", "top10.png");
+	set_pixmap ("image_fluid", "fluid.png");
+	set_pixmap ("image_keyboard", "key.png");
+	set_pixmap ("image_beep", "beep.png");
+	set_pixmap ("image_progress", "progress.png");
+	set_pixmap ("image_other", "other.png");
+	set_pixmap ("image_top10", "top10.png");
 
 	/* Set Top10 TreeViews
 	 */
@@ -383,7 +366,7 @@ main_window_init ()
 	/* Set big and bold labels
 	 */
 	pango_parse_markup ("<big><b>----------------------------------------------------------------</b></big>",
-		       	-1, 0, &palist, NULL, NULL, NULL);
+			    -1, 0, &palist, NULL, NULL, NULL);
 	gtk_label_set_attributes (GTK_LABEL (get_wg ("label_keyboard_title")), palist);
 	gtk_label_set_attributes (GTK_LABEL (get_wg ("label_main_intro")), palist);
 	gtk_label_set_attributes (GTK_LABEL (get_wg ("label_main_basic")), palist);
@@ -402,17 +385,13 @@ main_window_init ()
 	tmp = g_strdup_printf ("2 - %s", _("Adaptability"));
 	gtk_label_set_text (GTK_LABEL (get_wg ("label_main_adapt")), tmp);
 	g_free (tmp);
-	tmp = g_strdup_printf ("3 - %s", _("Velocity"));
+	tmp = g_strdup_printf ("3 - %s", _("Speed"));
 	gtk_label_set_text (GTK_LABEL (get_wg ("label_main_velo")), tmp);
 	g_free (tmp);
-	tmp = g_strdup_printf ("4 - %s", _("Fluidness"));
+	tmp = g_strdup_printf ("4 - %s", _("Fluidity"));
 	gtk_label_set_text (GTK_LABEL (get_wg ("label_main_fluid")), tmp);
 	g_free (tmp);
 
-	/* Set Sexy Icon Entry...
-	 */
-	tutor_entry_mesg_init (); 
-
 	/* Set version
 	 */
 	gtk_about_dialog_set_version (GTK_ABOUT_DIALOG (get_obj ("aboutdialog_klavaro")), VERSION);
@@ -448,7 +427,83 @@ main_window_init ()
 	}
 }
 
-/* Quit the application
+/*******************************************************************************
+ * Main program
+ */
+int
+main (int argc, char *argv[])
+{
+	gchar *tmp;
+	gboolean success = FALSE;
+	gboolean show_version = FALSE;
+	gboolean do_admin = FALSE;
+	GOptionContext *opct;
+	GOptionEntry option[] = {
+		{"version", 'v', 0, G_OPTION_ARG_NONE, &show_version, "", NULL},
+		{"admin", 'a', 0, G_OPTION_ARG_NONE, &do_admin, "", NULL},
+		{NULL}
+	};
+
+	/* Localization
+	 */
+#ifdef ENABLE_NLS
+	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
+#endif
+
+	/* Command-line arguments
+	 */
+	opct = g_option_context_new ("");
+	g_option_context_set_translation_domain (opct, GETTEXT_PACKAGE);
+	g_option_context_add_main_entries (opct, option, GETTEXT_PACKAGE);
+	g_option_context_add_group (opct, gtk_get_option_group (TRUE));
+	g_option_context_parse (opct, &argc, &argv, NULL);
+
+	if (show_version)
+	{
+		g_printf (VERSION"\n");
+		return 0;
+	}
+
+	if (do_admin)
+	{
+		main_initialize_global_variables ();
+		curl_ok = curl_global_init (CURL_GLOBAL_WIN32) == CURLE_OK ? TRUE : FALSE;
+		top10_global_rank ();
+		if (curl_ok)
+			curl_global_cleanup ();
+		return 0;
+	}
+
+	curl_ok = curl_global_init (CURL_GLOBAL_WIN32) == CURLE_OK ? TRUE : FALSE;
+
+	main_initialize_global_variables ();	/* Here the locale is got. */
+
+	/* Create all the interface stuff
+	 */
+	gui = gtk_builder_new ();
+	tmp = g_build_filename (main_path_data (), "klavaro.ui", NULL);
+	if (g_file_test (tmp, G_FILE_TEST_IS_REGULAR))
+		success = gtk_builder_add_from_file (gui, tmp, NULL);
+	else
+		g_error ("GUI file not found. Aborting.\n %s", tmp);
+	if (!success)
+		g_error ("GUI file found but couldn't create the GUI. Aborting.");
+	if (!g_module_supported ())
+		g_error ("GUI created but can't connect signals.");
+	g_free (tmp);
+	gtk_builder_connect_signals (gui, NULL);
+
+	main_window_init ();	/* and initialize its parameters */
+
+	gtk_main ();
+
+	return 0;
+}
+
+/*******************************************************************************
+ * Quit the application
  */
 void
 main_window_pass_away ()
@@ -457,13 +512,10 @@ main_window_pass_away ()
 
 	g_rmdir ("tmp/klavaro");
 
-	/*
-	 * Good bye
-	 */
-#ifdef G_OS_UNIX
-	if (general.curl_ok) curl_global_cleanup ();
-#endif
+	if (curl_ok)
+		curl_global_cleanup ();
 	g_print ("\nAdiaux!\n");
+
+	accur_close ();
 	exit (0);
 }
-
