@@ -10,15 +10,16 @@
 /*  along with this program.  If not, see <http://www.gnu.org/licenses/>.    */
 /*****************************************************************************/
 
+#include <sys/stat.h>
+
 #ifdef G_OS_UNIX
 # define UNIX_OK TRUE
 # define DIRSEP_S "/"
 # define DIRSEP '/'
 # define LESSON_FONT "Monospace 14"
 # define NORMAL_FONT "Sans 14"
-#endif
-
-#ifdef G_OS_WIN32
+# define DIR_PERM (S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH)
+#else
 # define UNIX_OK FALSE
 # define DIRSEP_S "\\"
 # define DIRSEP '\\'
@@ -28,6 +29,7 @@
 # define PACKAGE_LOCALE_DIR "..\\share\\locale"
 # undef PACKAGE_DATA_DIR
 # define PACKAGE_DATA_DIR "..\\share"
+# define DIR_PERM (0xFFFF)
 #endif
 
 #define LOCAL TRUE
@@ -36,15 +38,15 @@
 /*
  * Interface
  */
-gchar *main_get_data_path (void);
+gchar *main_path_user (void);
 
-void main_set_data_path (gchar * path);
+gchar *main_path_stats (void);
 
-gchar *main_get_user_dir (void);
+gchar *main_path_data (void);
 
-gchar *main_get_score_path (void);
+gchar *main_path_score (void);
 
-gboolean main_get_curl_ok (void);
+gboolean main_curl_ok (void);
 
 gboolean main_preferences_exist (gchar * group, gchar * key);
 
@@ -64,7 +66,5 @@ void main_preferences_set_boolean (gchar * group, gchar * key, gboolean value);
 
 void main_preferences_save (void);
 
-/* Initialization / destruction
- */
 void main_window_pass_away (void);
 
