@@ -34,4 +34,4 @@ void plot_initialize (void);
 
 void plot_draw_chart (gint field);
 
-void plot_pointer_update (gdouble x, gdouble y);
+void plot_pointer_update (gdouble x);
