@@ -34,16 +34,17 @@ static Lang_Name_Code *lang;
 static gint lang_num = 0;
 
 /**********************************************************************
- * Get country name from its ISO code
+ * Get country name from its "ISO code" (some are just languages...)
  */
 const gchar *
 trans_code_to_country (gchar *code)
 {
-#	define COUNTRY_N 50
+#	define COUNTRY_N 30
 	gsize i;
 	gchar *dummy = NULL;
 	static gchar map[COUNTRY_N][2][64] = {
 		{"xx","Esperantujo"},
+		{"ar","العالم العربي"},
 		{"be","België"},
 		{"br","Brasil"},
 		{"cz","Česká republika"},
@@ -57,7 +58,7 @@ trans_code_to_country (gchar *code)
 		{"il","מדינת ישראל"},
 		{"it","Italia"},
 		{"jp","日本 (Nippon)"},
-		{"no","Norge"},
+		{"nb","Norge"},
 		{"pl","Polska"},
 		{"pk","پاکستان"},
 		{"pt","Portugal"},
@@ -70,8 +71,6 @@ trans_code_to_country (gchar *code)
 		{"",""},
 		{"",""},
 		{"",""},
-		{"",""},
-		{"",""},
 		{"",""}
 	};
 
@@ -258,8 +257,8 @@ trans_lang_get_similar (gchar * test)
 void
 trans_init_language_env ()
 {
-	gchar *tmp_code = NULL;
-	gboolean lang_ok = TRUE;
+	gchar *tmp_code;
+	gboolean lang_ok;
 	gint i;
 
 	/*
@@ -277,7 +276,6 @@ trans_init_language_env ()
 			{
 				lang_ok = FALSE;
 				main_preferences_remove ("interface", "language");
-				g_free (tmp_code);
 			}
 			else
 				main_preferences_set_string ("interface", "language", tmp_code);
@@ -440,7 +438,6 @@ void
 trans_change_language (gchar *language)
 {
 	gint i;
-	GtkWidget *wg;
 
 	for (i = 0; i < lang_num; i++)
 		if (g_str_has_prefix (language, lang[i].name))
@@ -480,7 +477,7 @@ trans_lang_get_similar_file (const gchar * file_end)
 		{
 			g_free (tmp_path);
 			tmp_path =
-				g_strconcat (main_get_data_path (), G_DIR_SEPARATOR_S, lang[i].code, file_end, NULL);
+				g_strconcat (main_path_data (), G_DIR_SEPARATOR_S, lang[i].code, file_end, NULL);
 			fh = (FILE *) g_fopen (tmp_path, "r");
 		}
 	}
@@ -512,13 +509,13 @@ trans_lang_get_similar_file_name (const gchar * file_end)
 		{
 			g_free (tmp_path);
 			tmp_path =
-				g_strconcat (main_get_data_path (), G_DIR_SEPARATOR_S, lang[i].code, file_end, NULL);
+				g_strconcat (main_path_data (), G_DIR_SEPARATOR_S, lang[i].code, file_end, NULL);
 			if (g_file_test (tmp_path, G_FILE_TEST_IS_REGULAR))
 				break;
 		}
 	}
 	if (tmp_path == NULL)
-		tmp_path = g_strconcat (main_get_data_path (), G_DIR_SEPARATOR_S, "C", file_end, NULL);
+		tmp_path = g_strconcat (main_path_data (), G_DIR_SEPARATOR_S, "C", file_end, NULL);
 	g_free (tmp_code);
 	return (tmp_path);
 }
@@ -606,7 +603,7 @@ trans_read_text (const gchar * file_end)
 
 	/* Try at HOME
 	 */
-	tmp_path = g_build_filename (main_get_user_dir (), tmp_name, NULL);
+	tmp_path = g_build_filename (main_path_user (), tmp_name, NULL);
 	fh = (FILE *) g_fopen (tmp_path, "r");
 
 	/* Try at PACKAGE_DATA
@@ -614,7 +611,7 @@ trans_read_text (const gchar * file_end)
 	if (fh == NULL)
 	{
 		g_free (tmp_path);
-		tmp_path = g_build_filename (main_get_data_path (), tmp_name, NULL);
+		tmp_path = g_build_filename (main_path_data (), tmp_name, NULL);
 		fh = (FILE *) g_fopen (tmp_path, "r");
 	}
 
