@@ -23,7 +23,9 @@
  */
 
 #define LANG_SET \
+"العربية (ar) [qwerty_ar] \n" \
 " বাংলা (bn) [qwerty_us]\n" \
+"Bokmål (nb) [qwerty_nb]\n" \
 "Čeština (cs) [qwertz_cz]\n" \
 "Dansk (da) [qwerty_dk]\n" \
 "Deutsch (de) [qwertz_de]\n" \
@@ -32,6 +34,7 @@
 "Esperanto (eo) [dvorak_eo_eurokeys]\n" \
 "Español; Castellano (es) [qwerty_es]\n" \
 "Français (fr) [azerty_fr]\n" \
+"Galego (gl) [qwerty_es]\n" \
 "Magyar (hu) [qwertz_hu]\n" \
 "Nederlands (nl) [qwerty_us]\n" \
 "Polski (pl) [qwertz_pl]\n" \
