@@ -22,7 +22,6 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 #include <gtk/gtk.h>
-#include <libsexy/sexy-icon-entry.h>
 
 #include "main.h"
 #include "auxiliar.h"
@@ -34,6 +33,7 @@
 #include "adaptability.h"
 #include "velocity.h"
 #include "fluidness.h"
+#include "accuracy.h"
 #include "top10.h"
 #include "tutor.h"
 
@@ -83,6 +83,12 @@ tutor_set_query (TutorQuery query)
 	tutor.query = query;
 }
 
+gint
+tutor_get_correcting ()
+{
+	return (tutor.correcting);
+}
+
 void
 tutor_init_timers ()
 {
@@ -96,9 +102,10 @@ tutor_goal_accuracy ()
 	{
 		case TT_BASIC: return 95.0;
 		case TT_ADAPT: return 98.0;
-		case TT_VELO: return 97.0;
+		case TT_VELO: return 95.0;
 		case TT_FLUID: return 97.0;
 	}
+	return -1.0;
 }
 
 gdouble
@@ -111,6 +118,7 @@ tutor_goal_speed ()
 		case TT_VELO: return 50.0;
 		case TT_FLUID: return 50.0;
 	}
+	return -1.0;
 }
 
 gdouble
@@ -121,53 +129,9 @@ tutor_goal_fluidity ()
 		case TT_BASIC:
 		case TT_ADAPT:
 		case TT_VELO: return 0.0;
-		case TT_FLUID: return 75.0;
+		case TT_FLUID: return 70.0;
 	}
-}
-
-/* Sexy Icon Entry
- */
-static GtkWidget *entry_mesg = NULL;
-
-void
-on_entry_mesg_restart_clicked (SexyIconEntry *entry, gint pos, gint but, gpointer data)
-{
-	if (tutor_get_query () == QUERY_END)
-		return;
-
-	tutor_set_query (QUERY_INTRO);
-	tutor_process_touch (L'\0');
-}
-
-void
-tutor_entry_mesg_init ()
-{
-	GtkWidget *img;
-
-	img = gtk_image_new_from_stock (GTK_STOCK_CLEAR, GTK_ICON_SIZE_MENU);
-	entry_mesg = sexy_icon_entry_new ();
-	sexy_icon_entry_set_icon (SEXY_ICON_ENTRY (entry_mesg), SEXY_ICON_ENTRY_SECONDARY, GTK_IMAGE (img));
-	sexy_icon_entry_set_icon_highlight (SEXY_ICON_ENTRY (entry_mesg), SEXY_ICON_ENTRY_SECONDARY, TRUE);
-
-	gtk_widget_destroy (get_wg ("entry_mesg"));
-	gtk_box_pack_start_defaults (GTK_BOX (get_wg ("hbox_bottom_mesg")), entry_mesg);
-	gtk_box_reorder_child (GTK_BOX (get_wg ("hbox_bottom_mesg")), entry_mesg, 0);
-
-	g_signal_connect (G_OBJECT (entry_mesg), "icon-pressed", (GCallback) on_entry_mesg_restart_clicked, NULL);
-	g_signal_connect (G_OBJECT (entry_mesg), "drag-drop", (GCallback) on_entry_mesg_drag_drop, NULL);
-	g_signal_connect_after (G_OBJECT (entry_mesg), "focus-out-event", (GCallback) on_entry_mesg_focus_out_event, NULL);
-	g_signal_connect_after (G_OBJECT (entry_mesg), "grab-focus", (GCallback) on_entry_mesg_grab_focus, NULL);
-	g_signal_connect_after (G_OBJECT (entry_mesg), "activate", (GCallback) on_entry_mesg_activate, NULL);
-	g_signal_connect_after (G_OBJECT (entry_mesg), "delete-text", (GCallback) on_entry_mesg_delete_text, NULL);
-	g_signal_connect_after (G_OBJECT (entry_mesg), "insert-text", (GCallback) on_entry_mesg_insert_text, NULL);
-
-	gtk_widget_show (entry_mesg);
-}
-
-GtkWidget *
-tutor_entry_mesg ()
-{
-	return (entry_mesg);
+	return -1.0;
 }
 
 /**********************************************************************
@@ -179,15 +143,14 @@ tutor_init (TutorType tt_type)
 	gchar *tmp_title = NULL;
 	gchar *tmp_name = NULL;
 	GtkWidget *wg;
-	GtkTooltipsData *tt;
 
 	gtk_widget_hide (get_wg ("window_main"));
 	gtk_widget_hide (get_wg ("window_keyboard"));
 	gtk_widget_hide (get_wg ("dialog_info"));
 	gtk_widget_hide (get_wg ("aboutdialog_klavaro"));
+	gtk_widget_hide (get_wg ("kadro_tro_eraroj"));
 	gtk_widget_show (get_wg ("window_tutor"));
-	//gtk_widget_grab_focus (get_wg ("entry_mesg"));
-	gtk_widget_grab_focus (entry_mesg); // Sexy Icon Entry...
+	gtk_widget_grab_focus (get_wg ("entry_mesg"));
 
 	tutor.type = tt_type;
 	cursor_set_blink (FALSE);
@@ -195,6 +158,8 @@ tutor_init (TutorType tt_type)
 	/******************************
 	 * Set the layout for each exercise type
 	 */
+	if (!UNIX_OK)
+		gtk_widget_hide (get_wg ("button_tutor_top10"));
 	gtk_widget_hide (get_wg ("entry_custom_basic_lesson"));
 	if (tutor.type == TT_BASIC || tutor.type == TT_FLUID)
 	{
@@ -214,7 +179,8 @@ tutor_init (TutorType tt_type)
 		else
 		{
 			gtk_widget_hide (get_wg ("togglebutton_edit_basic_lesson"));
-			gtk_widget_show (get_wg ("button_tutor_top10"));
+			if (UNIX_OK)
+				gtk_widget_show (get_wg ("button_tutor_top10"));
 			gtk_widget_hide (get_wg ("button_tutor_show_keyb"));
 			gtk_label_set_text (GTK_LABEL (get_wg ("label_lesson")), _("Paragraphs:"));
 			callbacks_shield_set (TRUE);
@@ -282,9 +248,9 @@ tutor_init (TutorType tt_type)
 	 * Set tooltips of tutor entry (drag and drop)
 	 */
 	if (tutor.type == TT_VELO || tutor.type == TT_FLUID)
-		gtk_widget_set_tooltip_text (entry_mesg, _("Drag and drop text here to practice with it.")); // Sexy...
+		gtk_widget_set_tooltip_text (get_wg ("entry_mesg"), _("Drag and drop text here to practice with it."));
 	else
-		gtk_widget_set_tooltip_text (entry_mesg, _("Press here to restart the exercise. Hotkey: [Ctrl R]")); //Sexy...
+		gtk_widget_set_tooltip_text (get_wg ("entry_mesg"), "");
 
 	/******************************
 	 * Set specific variables
@@ -576,7 +542,7 @@ tutor_eval_forward (gunichar user_chr)
 {
 	gunichar real_chr;
 
-	if (user_chr == L'\b')
+	if (user_chr == L'\b' || user_chr == L'\t')
 	{
 		tutor_beep ();
 		return (TRUE);
@@ -586,16 +552,26 @@ tutor_eval_forward (gunichar user_chr)
 
 	real_chr = cursor_get_char ();
 
+	// Minimizing the line breaking bug:
+	if (user_chr == UPSYM && real_chr == L' ')
+		user_chr = L' ';
+
 	/*
 	 * Compare the user char with the real char and set the color
 	 */
 	if (user_chr == real_chr)
+	{
 		cursor_paint_char ("char_correct");
+		if (tutor.type != TT_BASIC)
+			accur_correct (real_chr);
+	}
 	else
 	{
 		tutor_beep ();
 		cursor_paint_char ("char_wrong");
 		tutor.n_errors++;
+		if (tutor.type != TT_BASIC)
+			accur_wrong (real_chr);
 	}
 
 
@@ -677,6 +653,10 @@ tutor_eval_forward_backward (gunichar user_chr)
 
 	real_chr = cursor_get_char ();
 
+	// Minimizing the line breaking bug:
+	if (user_chr == UPSYM && real_chr == L' ')
+		user_chr = L' ';
+
 	/*
 	 * Compare the user char with the real char and set the color
 	 */
@@ -696,7 +676,10 @@ tutor_eval_forward_backward (gunichar user_chr)
 			tutor.n_errors++;
 		}
 		else
+		{
 			cursor_paint_char ("char_correct");
+			accur_correct (real_chr);
+		}
 	}
 	else
 	{
@@ -704,6 +687,8 @@ tutor_eval_forward_backward (gunichar user_chr)
 		cursor_paint_char ("char_wrong");
 		tutor_beep ();
 		tutor.retro_pos++;
+		if (tutor.retro_pos == 1)
+			accur_wrong (real_chr);
 	}
 
 	if (tutor.correcting > 0)
@@ -760,6 +745,8 @@ tutor_calc_stats ()
 	struct tm *ltime;
 	GtkWidget *wg;
 	GtkTextBuffer *buf;
+	GtkTextIter start;
+	GtkTextIter end;
 	Statistics stat;
 
 	/*
@@ -770,7 +757,7 @@ tutor_calc_stats ()
 
 	accuracy = 100 * (1.0 - (gfloat) tutor.n_errors / tutor.n_touchs);
 	touchs_per_second = (gdouble) (tutor.n_touchs - tutor.n_errors) / tutor.elapsed_time;
-	velocity = 10 * touchs_per_second;
+	velocity = 12 * touchs_per_second; // touched: new_WPM = 1.2 old_WPM
 
 	if (tutor.type == TT_FLUID)
 	{
@@ -837,7 +824,7 @@ tutor_calc_stats ()
 		 * Logging
 		 */
 		tmp_name =
-			g_strconcat (main_get_user_dir (), G_DIR_SEPARATOR_S "stat_", tutor_get_type_name (), ".txt",
+			g_strconcat (main_path_stats (), G_DIR_SEPARATOR_S "stat_", tutor_get_type_name (), ".txt",
 				     NULL);
 		assert_user_dir ();
 		if (!(fh = (FILE *) g_fopen (tmp_name, "r")))
@@ -887,7 +874,7 @@ tutor_calc_stats ()
 		{
 			/* Log the fluidness results of the last session
 			 */
-			tmp_name = g_build_filename (main_get_user_dir (), "deviation_fluid.txt", NULL);
+			tmp_name = g_build_filename (main_path_stats (), "deviation_fluid.txt", NULL);
 			if ((fh = (FILE *) g_fopen (tmp_name, "w")))
 			{
 				g_message ("writing further fluidness results at:\n %s", tmp_name);
@@ -937,27 +924,23 @@ tutor_calc_stats ()
 						g_strdup (_
 							  ("ps.: you have entered the Top 10 list, great!"));
 					top10_write_stats (LOCAL, -1);
-					if (main_preferences_get_boolean ("game", "autopublish"))
+					if (main_preferences_get_boolean ("game", "autopublish") && UNIX_OK)
 					{
 						top10_show_stats (LOCAL);
 						top10_show_stats (GLOBAL);
-#ifdef G_OS_UNIX
 						top10_global_publish (NULL);
-#endif
 					}
 				}
 			}
 			else
-				contest_ps =
-					g_strdup (_
-						  ("ps.: the text you just typed doesn't seem to be similar"
+				contest_ps = g_strdup (_("ps.: the text you just typed doesn't seem to be similar"
 						   " to ordinary texts in the language currently selected:"
 						   " we can't account for it in the 'Top 10' contest."));
 
 			/* Anyway, log also the scoring
 			 */
 			tmp_name =
-				g_build_filename (main_get_user_dir (), "scores_fluid.txt", NULL);
+				g_build_filename (main_path_stats (), "scores_fluid.txt", NULL);
 			assert_user_dir ();
 			if (!g_file_test (tmp_name, G_FILE_TEST_IS_REGULAR))
 			{
@@ -992,86 +975,140 @@ tutor_calc_stats ()
 	/*
 	 * Print statistics
 	 */
-	if (tutor.type == TT_BASIC || tutor.type == TT_ADAPT)
-	{
-		tmp_str = g_strconcat ("\n", _("STATISTICS"), "\n",
-				       _("Elapsed time:"), " %i ",
-				       dngettext (PACKAGE, "minute and",
-						  "minutes and", minutes),
-				       " %i ", dngettext (PACKAGE, "second",
-							  "seconds", seconds),
-				       "\n", _("Error ratio:"), " %i/%i\n", _("Accuracy:"),
-				       " %.1f%%\t\t", _("Goal:"), " %.0f%%\n\n", _("Comments:"),
-				       "\n", NULL);
-	}
-
 	wg = get_wg ("text_tutor");
 	buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (wg));
 
+	// Begin the accuracy
+	tmp_str = g_strconcat ("\n", _("STATISTICS"), "\n",
+			       _("Elapsed time:"), " %i ",
+			       dngettext (PACKAGE, "minute and", "minutes and", minutes),
+			       " %i ", dngettext (PACKAGE, "second", "seconds", seconds),
+			       "\n", _("Error ratio:"), " %i/%i\n", _("Accuracy:"), " ", NULL);
+
+	tmp_str2 = g_strdup_printf (tmp_str, minutes, seconds, tutor.n_errors, tutor.n_touchs);
+	gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
+
+	// Paint the accuracy
+	g_free (tmp_str2);
+	tmp_str2 = g_strdup_printf ("%.1f%%", accuracy);
+	gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
+
+	gtk_text_buffer_get_end_iter (buf, &start);
+	gtk_text_buffer_get_end_iter (buf, &end);
+	gtk_text_iter_backward_cursor_positions (&start, strlen (tmp_str2));
+	if (accuracy > tutor_goal_accuracy ())
+		gtk_text_buffer_apply_tag_by_name (buf, "char_correct", &start, &end);
+	else
+		gtk_text_buffer_apply_tag_by_name (buf, "char_wrong", &start, &end);
+
+	// Finish the accuracy
+	g_free (tmp_str2);
+	tmp_str2 = g_strdup_printf ("\t\t%s %.0f%%\n", _("Goal:"), tutor_goal_accuracy ());
+	gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
+
+	if (tutor.type == TT_VELO || tutor.type == TT_FLUID)
+	{
+		// Begin the CPS
+		g_free (tmp_str2);
+		tmp_str2 = g_strdup_printf ("%s ", _("Characters per second:"));
+		gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
+
+		// Paint the CPS
+		g_free (tmp_str2);
+		tmp_str2 = g_strdup_printf ("%.2f", velocity / 12);
+		gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
+
+		gtk_text_buffer_get_end_iter (buf, &start);
+		gtk_text_buffer_get_end_iter (buf, &end);
+		gtk_text_iter_backward_cursor_positions (&start, strlen (tmp_str2));
+		if (velocity > tutor_goal_speed ())
+			gtk_text_buffer_apply_tag_by_name (buf, "char_correct", &start, &end);
+		else
+			gtk_text_buffer_apply_tag_by_name (buf, "char_wrong", &start, &end);
+
+		// Finish the CPS
+		g_free (tmp_str2);
+		tmp_str2 = g_strdup_printf ("\t\t%s %.1f %s\n", _("Goal:"), tutor_goal_speed () / 12, _("(CPS)"));
+		gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
+
+		// Begin the WPM
+		g_free (tmp_str2);
+		tmp_str2 = g_strdup_printf ("%s ", _("Words per minute:"));
+		gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
+
+		// Paint the WPM
+		g_free (tmp_str2);
+		tmp_str2 = g_strdup_printf ("%.1f", velocity);
+		gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
+
+		gtk_text_buffer_get_end_iter (buf, &start);
+		gtk_text_buffer_get_end_iter (buf, &end);
+		gtk_text_iter_backward_cursor_positions (&start, strlen (tmp_str2));
+		if (velocity > tutor_goal_speed ())
+			gtk_text_buffer_apply_tag_by_name (buf, "char_correct", &start, &end);
+		else
+			gtk_text_buffer_apply_tag_by_name (buf, "char_wrong", &start, &end);
+
+		// Finish the WPM
+		g_free (tmp_str2);
+		tmp_str2 = g_strdup_printf ("\t\t%s %.0f %s\n", _("Goal:"), tutor_goal_speed (), _("(WPM)"));
+		gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
+
+		if (tutor.type == TT_FLUID)
+		{
+			// Begin the fluidity
+			g_free (tmp_str2);
+			tmp_str2 = g_strdup_printf ("%s ", _("Fluidness:"));
+			gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
+
+			// Paint the fluidity
+			g_free (tmp_str2);
+			tmp_str2 = g_strdup_printf ("%.1f%%", fluidness);
+			gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
+
+			gtk_text_buffer_get_end_iter (buf, &start);
+			gtk_text_buffer_get_end_iter (buf, &end);
+			gtk_text_iter_backward_cursor_positions (&start, strlen (tmp_str2));
+			if (fluidness > tutor_goal_fluidity ())
+				gtk_text_buffer_apply_tag_by_name (buf, "char_correct", &start, &end);
+			else
+				gtk_text_buffer_apply_tag_by_name (buf, "char_wrong", &start, &end);
+
+			// Finish the fluidity and scores
+			g_free (tmp_str2);
+			tmp_str2 = g_strdup_printf ("\t\t%s %.0f%%\n%s: %f\n",
+				       	_("Goal:"), tutor_goal_fluidity (),
+				       	_("Score"), stat.score);
+			gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
+		}
+	}
+
+	// Begin the comments
+	g_free (tmp_str2);
+	tmp_str2 = g_strdup_printf ("\n%s\n", _("Comments:"));
+	gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
+
 	switch (tutor.type)
 	{
 	case TT_BASIC:
-		tmp_str2 =
-			g_strdup_printf (tmp_str, minutes, seconds, tutor.n_errors, tutor.n_touchs,
-					 accuracy, tutor_goal_accuracy ());
-		gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
 		basic_comment (accuracy);
 		break;
 	case TT_ADAPT:
-		tmp_str2 =
-			g_strdup_printf (tmp_str, minutes, seconds, tutor.n_errors, tutor.n_touchs,
-					 accuracy, tutor_goal_accuracy ());
-		gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
 		adapt_comment (accuracy);
 		break;
 	case TT_VELO:
-		tmp_str = g_strconcat ("\n", _("STATISTICS"), "\n",
-				       _("Elapsed time:"), " %i ",
-				       dngettext (PACKAGE, "minute and",
-						  "minutes and", minutes),
-				       " %i ", dngettext (PACKAGE, "second",
-							  "seconds", seconds),
-				       "\n", _("Error ratio:"), " %i/%i\n", _("Accuracy:"),
-				       " %.1f%%\t\t", _("Goal:"), " %.0f%%", "\n",
-				       _("Characters per second:"), " %.2f\t\t", _("Goal:"), " %.1f ",
-				       _("(CPS)"), "\n", _("Words per minute:"), " %.1f\t\t",
-				       _("Goal:"), " %.0f ", _("(WPM)"), "\n\n", _("Comments:"), "\n",
-				       NULL);
-		tmp_str2 =
-			g_strdup_printf (tmp_str, minutes, seconds, tutor.n_errors, tutor.n_touchs,
-					 accuracy, tutor_goal_accuracy (),
-					 velocity / 10, tutor_goal_speed () / 10,
-					 velocity, tutor_goal_speed ());
-		gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
 		velo_comment (accuracy, velocity);
 		break;
 	case TT_FLUID:
-		tmp_str = g_strconcat ("\n", _("STATISTICS"), "\n",
-				       _("Elapsed time:"), " %i ",
-				       dngettext (PACKAGE, "minute and",
-						  "minutes and", minutes),
-				       " %i ", dngettext (PACKAGE, "second",
-							  "seconds", seconds),
-				       "\n", _("Error ratio:"), " %i/%i\n", _("Accuracy:"),
-				       " %.1f%%\t\t", _("Goal:"), " %.0f%%", "\n",
-				       _("Characters per second:"), " %.2f\t\t", _("Goal:"), " %.1f ",
-				       _("(CPS)"), "\n", _("Words per minute:"), " %.1f\t\t",
-				       _("Goal:"), " %.0f ", _("(WPM)"), "\n", _("Fluidness:"),
-				       " %.1f%%\t\t", _("Goal:"), " %.0f%%\n", _("Score"),
-				       ": %f\n\n", _("Comments:"), "\n", NULL);
-		tmp_str2 =
-			g_strdup_printf (tmp_str, minutes, seconds, tutor.n_errors, tutor.n_touchs,
-					 accuracy, tutor_goal_accuracy (),
-					 velocity / 10, tutor_goal_speed () / 10,
-					 velocity, tutor_goal_speed (),
-					 fluidness, tutor_goal_fluidity (), stat.score);
-		gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
 		fluid_comment (accuracy, velocity, fluidness);
 
 		if (contest_ps != NULL)
 		{
-			gtk_text_buffer_insert_at_cursor (buf, "\n", 1);
-			gtk_text_buffer_insert_at_cursor (buf, contest_ps, strlen (contest_ps));
+			if (UNIX_OK)
+			{
+				gtk_text_buffer_insert_at_cursor (buf, "\n", 1);
+				gtk_text_buffer_insert_at_cursor (buf, contest_ps, strlen (contest_ps));
+			}
 			g_free (contest_ps);
 		}
 		break;
@@ -1114,7 +1151,7 @@ tutor_char_distribution_approved ()
 	/* Get model text
 	 */
 	tmp_code = main_preferences_get_string ("interface", "language");
-	tmp_name = g_strconcat (main_get_data_path (), G_DIR_SEPARATOR_S, tmp_code, ".paragraphs", NULL);
+	tmp_name = g_strconcat (main_path_data (), G_DIR_SEPARATOR_S, tmp_code, ".paragraphs", NULL);
 	g_free (tmp_code);
 	if (!g_file_get_contents (tmp_name, &model.text, NULL, NULL))
 	{
@@ -1160,11 +1197,11 @@ tutor_char_distribution_approved ()
 	}
 	deceiveness = sqrtf (deceiveness / 9);
 
-	g_message ("model file: %s", tmp_name);
+	g_print ("Corpus file: %s\n", tmp_name);
 	if (deceiveness < DECEIVENESS_LIMIT)
-		g_print ("Deceiveness: %.3f. OK, it is less than %.3f.\n", deceiveness, DECEIVENESS_LIMIT);
+		g_print ("\tDeviation: %.3f. OK, it is less than %.3f.\n", deceiveness, DECEIVENESS_LIMIT);
 	else
-		g_print ("Deceiveness: %.3f. It should be less than %.3f.\n", deceiveness, DECEIVENESS_LIMIT);
+		g_print ("\tDeviation: %.3f! It should be less than %.3f.\n", deceiveness, DECEIVENESS_LIMIT);
 
 	g_free (tmp_name);
 	g_free (model.text);
@@ -1309,10 +1346,7 @@ tutor_message (gchar * mesg)
 		return;
 	}
 
-	if (entry_mesg == NULL) return; // Sexy Icon Entry...
-	wg = entry_mesg; // Sexy...
-	//wg = get_wg ("entry_mesg");
-
+	wg = get_wg ("entry_mesg");
 	callbacks_shield_set (TRUE);
 	gtk_editable_delete_text (GTK_EDITABLE (wg), 0, -1);
 	gtk_editable_insert_text (GTK_EDITABLE (wg), g_strdup (mesg), strlen (mesg), &pos);
@@ -1353,7 +1387,7 @@ tutor_load_list_other (gchar * file_name_end, GtkListStore * list)
 	gtk_list_store_set (list, &iter, 0, defstr, -1);
 
 	assert_user_dir ();
-	dir = g_dir_open (main_get_user_dir (), 0, NULL);
+	dir = g_dir_open (main_path_user (), 0, NULL);
 	while ((dentry = g_strdup (g_dir_read_name (dir))) != NULL)
 	{
 		if (strlen (dentry) < 5)
@@ -1408,8 +1442,8 @@ tutor_other_rename (const gchar *new_tx, const gchar *old_tx)
 			old_name = g_strconcat (old_tx, ".paragraphs", NULL);
 			new_name = g_strconcat (new_tx, ".paragraphs", NULL);
 		}
-		old_file = g_build_filename (main_get_user_dir (), old_name);
-		new_file = g_build_filename (main_get_user_dir (), new_name);
+		old_file = g_build_filename (main_path_user (), old_name, NULL);
+		new_file = g_build_filename (main_path_user (), new_name, NULL);
 
 		if (g_file_test (new_file, G_FILE_TEST_IS_REGULAR))
 		{
