@@ -95,7 +95,7 @@ velo_init_dict (gchar * list_name)
 	if (list_name && !g_str_equal (list_name, OTHER_DEFAULT) )
 	{
 		main_preferences_set_string ("tutor", "word_list", list_name);
-		tmp_name = g_strconcat (main_get_user_dir (), G_DIR_SEPARATOR_S, list_name, ".words", NULL);
+		tmp_name = g_strconcat (main_path_user (), G_DIR_SEPARATOR_S, list_name, ".words", NULL);
 		g_message ("loading dictionary: %s.words", list_name);
 		dict_name = g_strdup (list_name);
 	}
@@ -103,7 +103,7 @@ velo_init_dict (gchar * list_name)
 	{
 		main_preferences_remove ("tutor", "word_list");
 		tmp_code = main_preferences_get_string ("interface", "language");
-		tmp_name = g_strconcat (main_get_data_path (), G_DIR_SEPARATOR_S, tmp_code, ".words", NULL);
+		tmp_name = g_strconcat (main_path_data (), G_DIR_SEPARATOR_S, tmp_code, ".words", NULL);
 		g_message ("loading dictionary: %s.words", tmp_code);
 		g_free (tmp_code);
 		dict_name = g_strdup ("Default");
@@ -307,7 +307,7 @@ velo_text_write_to_file (gchar * text_raw, gboolean overwrite)
 	FILE *fh_destiny;
 
 	dictio_name = g_strdup_printf ("(%s)", _("Pasted_or_dropped"));
-	dict_path = g_strconcat (main_get_user_dir (), G_DIR_SEPARATOR_S, dictio_name, ".words", NULL);
+	dict_path = g_strconcat (main_path_user (), G_DIR_SEPARATOR_S, dictio_name, ".words", NULL);
 	assert_user_dir ();
 	if (!(fh_destiny = (FILE *) g_fopen (dict_path, "w")))
 	{
@@ -368,7 +368,7 @@ velo_create_dict (gchar * file_name, gboolean overwrite)
 	}
 
 	dictio_name = g_path_get_basename (file_name);
-	dict_path = g_strconcat (main_get_user_dir (), G_DIR_SEPARATOR_S, dictio_name, ".words", NULL);
+	dict_path = g_strconcat (main_path_user (), G_DIR_SEPARATOR_S, dictio_name, ".words", NULL);
 	assert_user_dir ();
 	if (!(fh_destiny = (FILE *) g_fopen (dict_path, "w")))
 	{
@@ -415,9 +415,14 @@ velo_comment (gdouble accuracy, gdouble velocity)
 	 * Comments
 	 */
 	if (accuracy < tutor_goal_accuracy ())
+	{
+		/*
 		tmp_str = g_strdup_printf (_(" Your accuracy rate is not good enough.\n"
 				      " I only can rely on you if it is greater than %.0f%%.\n"
 				      " Please calm down and try it again.\n"), tutor_goal_accuracy ());
+		*/
+		tmp_str = g_strdup (":-(\n");
+	}
 	else if (velocity < 10)
 		tmp_str =
 			g_strdup (_(" You are just beginning.\n"
